@@ -1,6 +1,5 @@
 #
-# Copyright (C) 2011 - 2018 Satoru SATOH <ssato@redhat.com>
-# Copyright (C) 2019 - 2020 Satoru SATOH <satoru.satoh@gmail.com>
+# Copyright (C) 2011 - 2021 Satoru SATOH <satoru.satoh@gmail.com>
 # SPDX-License-Identifier: MIT
 #
 # Ref. python -c "import json; help(json)"
@@ -33,11 +32,9 @@ Changelog:
 
 .. versionadded:: 0.0.1
 """
-from __future__ import absolute_import
-
 import json
-import anyconfig.backend.base
 
+from .. import base
 from .common import Parser as BaseParser
 
 
@@ -45,12 +42,12 @@ class Parser(BaseParser):
     """
     Parser for JSON files.
     """
-    _cid = "std.json"
+    _cid = 'std.json'
     _priority = 30  # Higher priority than others.
 
-    _load_from_string_fn = anyconfig.backend.base.to_method(json.loads)
-    _load_from_stream_fn = anyconfig.backend.base.to_method(json.load)
-    _dump_to_string_fn = anyconfig.backend.base.to_method(json.dumps)
-    _dump_to_stream_fn = anyconfig.backend.base.to_method(json.dump)
+    _load_from_string_fn = base.to_method(json.loads)
+    _load_from_stream_fn = base.to_method(json.load)
+    _dump_to_string_fn = base.to_method(json.dumps)
+    _dump_to_stream_fn = base.to_method(json.dump)
 
 # vim:sw=4:ts=4:et:
