@@ -4,10 +4,9 @@
 #
 # pylint: disable=missing-docstring,invalid-name,too-few-public-methods
 # pylint: disable=ungrouped-imports
-from __future__ import absolute_import
 
 try:
-    import anyconfig.backend.json._simplejson as TT
+    import anyconfig.backend.json.simplejson as TT
 except ImportError:
     import unittest
     raise unittest.SkipTest
